| Type: | Package |
| Title: | 'ALS-Binary': Allele Size to Binary Converter |
| Version: | 1.0.0 |
| Description: | Converts microsatellite allele sizes into binary matrices and provides a 'Shiny' interface. |
| Depends: | R (≥ 4.3.0) |
| Imports: | shiny, readr, readxl, DT |
| Suggests: | testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| License: | GPL-3 |
| Encoding: | UTF-8 |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-08-01 11:28:07 UTC; vppra |
| Author: | Prasanth VP [aut, cre], Subhash Chandra [aut] |
| Maintainer: | Prasanth VP <prasanth.stat@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-08-08 11:40:02 UTC |
Convert allele sizes to binary
Description
This function converts microsatellite allele sizes into binary matrices.
Usage
allele_to_binary(data, repeat_lengths)
Arguments
data |
Input data frame with Marker, Genotype, and allele sizes |
repeat_lengths |
Repeat length info |
Value
A list of binary matrices
Alias: als_binary
Description
Alias: als_binary
Usage
als_binary()
Value
A shiny.appobj object representing the Shiny application.
Run ALS-Binary Shiny App
Description
Run ALS-Binary Shiny App
Usage
runALSBinaryApp()
Value
A shiny.appobj object representing the Shiny application.
Alias: run_app
Description
Alias: run_app
Usage
run_app()
Value
A shiny.appobj object representing the Shiny application.